import { defineComponent, computed, openBlock, createBlock, createVNode, inject as inject$1, ref, watchEffect, createTextVNode, toDisplayString, resolveComponent, createCommentVNode, Fragment, renderList, pushScopeId, popScopeId, withScopeId } from 'vue';
import { matchSorter } from 'match-sorter';
import { inject } from 'vue-demi';

var Position;
(function (Position) {
    Position["TR"] = "top-right";
    Position["TL"] = "top-left";
    Position["BR"] = "bottom-right";
    Position["BL"] = "bottom-left";
})(Position || (Position = {}));
function isStale(query) {
    return typeof query.isStale === "function"
        ? query.isStale()
        :
            query.state.isStale;
}
function getQueryStatusColor(query, theme) {
    return query.state.isFetching
        ? theme.active
        : isStale(query)
            ? theme.warning
            :
                !query.observers.length
                    ? theme.gray
                    : theme.success;
}
function getQueryStatusLabel(query) {
    return query.state.isFetching
        ? "fetching"
        :
            !query.observers.length
                ? "inactive"
                : isStale(query)
                    ? "stale"
                    : "fresh";
}
const getStatusRank = (query) => query.state.isFetching
    ? 0
    :
        !query.observers.length
            ? 3
            : isStale(query)
                ? 2
                : 1;
const sortFns = {
    "Status > Last Updated": (a, b) => getStatusRank(a) === getStatusRank(b)
        ? sortFns["Last Updated"](a, b)
        : getStatusRank(a) > getStatusRank(b)
            ? 1
            : -1,
    "Query Hash": (a, b) => (a.queryHash > b.queryHash ? 1 : -1),
    "Last Updated": (a, b) => (a.state.updatedAt < b.state.updatedAt ? 1 : -1),
};

var script$5 = defineComponent({
    name: "CloseButton",
    props: {
        position: {
            type: String,
            required: true,
        },
        buttonProps: {
            type: Object,
            default: {},
        },
    },
    emits: ["click"],
    setup(props, context) {
        const onClick = () => {
            var _a, _b;
            context.emit("click");
            (_b = (_a = props.buttonProps).click) === null || _b === void 0 ? void 0 : _b.call(_a);
        };
        const buttonStyles = computed(() => (Object.assign(Object.assign({ position: "fixed", zIndex: "99999", margin: ".5rem", bottom: 0 }, (props.position === Position.TR
            ? {
                right: "0",
            }
            : props.position === Position.TL
                ? {
                    left: "0",
                }
                : props.position === Position.BR
                    ? {
                        right: "0",
                    }
                    : {
                        left: "0",
                    })), props.buttonProps.style)));
        return {
            onClick,
            buttonStyles,
        };
    },
});

function render$5(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createBlock("button", {
    type: "button",
    onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.onClick && _ctx.onClick(...args))),
    style: _ctx.buttonStyles
  }, "Close", 4 /* STYLE */))
}

script$5.render = render$5;
script$5.__file = "src/devtools/CloseButton.vue";

const VUE_QUERY_CLIENT = "VUE_QUERY_CLIENT";
function useQueryClient() {
    const queryClient = inject(VUE_QUERY_CLIENT);
    if (!queryClient) {
        throw new Error("No queryClient found in Vue context, use 'app.provide(VUE_QUERY_CLIENT, new QueryClient());' to set one in root component.");
    }
    return queryClient;
}

const _hoisted_1$3 = {
  width: "40px",
  height: "40px",
  viewBox: "0 0 190 190",
  version: "1.1"
};
const _hoisted_2$2 = /*#__PURE__*/createVNode("g", {
  id: "Page-1",
  stroke: "none",
  strokeWidth: "1",
  fill: "none",
  fillRule: "evenodd"
}, [
  /*#__PURE__*/createVNode("g", {
    id: "og-white",
    transform: "translate(-33.000000, 0.000000)"
  }, [
    /*#__PURE__*/createVNode("path", {
      d: "M72.7239712,61.3436237 C69.631224,46.362877 68.9675112,34.8727722 70.9666331,26.5293551 C72.1555965,21.5671678 74.3293088,17.5190846 77.6346064,14.5984631 C81.1241394,11.5150478 85.5360327,10.0020122 90.493257,10.0020122 C98.6712013,10.0020122 107.26826,13.7273214 116.455725,20.8044264 C120.20312,23.6910458 124.092437,27.170411 128.131651,31.2444746 C128.45314,30.8310265 128.816542,30.4410453 129.22143,30.0806152 C140.64098,19.9149716 150.255245,13.5989272 158.478408,11.1636507 C163.367899,9.715636 167.958526,9.57768202 172.138936,10.983031 C176.551631,12.4664684 180.06766,15.5329489 182.548314,19.8281091 C186.642288,26.9166735 187.721918,36.2310983 186.195595,47.7320243 C185.573451,52.4199112 184.50985,57.5263831 183.007094,63.0593153 C183.574045,63.1277086 184.142416,63.2532808 184.705041,63.4395297 C199.193932,68.2358678 209.453582,73.3937462 215.665021,79.2882839 C219.360669,82.7953831 221.773972,86.6998434 222.646365,91.0218204 C223.567176,95.5836746 222.669313,100.159332 220.191548,104.451297 C216.105211,111.529614 208.591643,117.11221 197.887587,121.534031 C193.589552,123.309539 188.726579,124.917559 183.293259,126.363748 C183.541176,126.92292 183.733521,127.516759 183.862138,128.139758 C186.954886,143.120505 187.618598,154.61061 185.619477,162.954027 C184.430513,167.916214 182.256801,171.964297 178.951503,174.884919 C175.46197,177.968334 171.050077,179.48137 166.092853,179.48137 C157.914908,179.48137 149.31785,175.756061 140.130385,168.678956 C136.343104,165.761613 132.410866,162.238839 128.325434,158.108619 C127.905075,158.765474 127.388968,159.376011 126.77857,159.919385 C115.35902,170.085028 105.744755,176.401073 97.5215915,178.836349 C92.6321009,180.284364 88.0414736,180.422318 83.8610636,179.016969 C79.4483686,177.533532 75.9323404,174.467051 73.4516862,170.171891 C69.3577116,163.083327 68.2780823,153.768902 69.8044053,142.267976 C70.449038,137.410634 71.56762,132.103898 73.1575891,126.339009 C72.5361041,126.276104 71.9120754,126.144816 71.2949591,125.940529 C56.8060684,121.144191 46.5464184,115.986312 40.3349789,110.091775 C36.6393312,106.584675 34.2260275,102.680215 33.3536352,98.3582381 C32.4328237,93.7963839 33.3306866,89.2207269 35.8084524,84.9287618 C39.8947886,77.8504443 47.4083565,72.2678481 58.1124133,67.8460273 C62.5385143,66.0176154 67.5637208,64.366822 73.1939394,62.8874674 C72.9933393,62.3969171 72.8349374,61.8811235 72.7239712,61.3436237 Z",
      id: "Path",
      fill: "#002C4B",
      fillRule: "nonzero",
      transform: "translate(128.000000, 95.000000) scale(-1, 1) translate(-128.000000, -95.000000) "
    }),
    /*#__PURE__*/createVNode("path", {
      d: "M113.396882,64 L142.608177,64 C144.399254,64 146.053521,64.958025 146.944933,66.5115174 L161.577138,92.0115174 C162.461464,93.5526583 162.461464,95.4473417 161.577138,96.9884826 L146.944933,122.488483 C146.053521,124.041975 144.399254,125 142.608177,125 L113.396882,125 C111.605806,125 109.951539,124.041975 109.060126,122.488483 L94.4279211,96.9884826 C93.543596,95.4473417 93.543596,93.5526583 94.4279211,92.0115174 L109.060126,66.5115174 C109.951539,64.958025 111.605806,64 113.396882,64 Z M138.987827,70.2765273 C140.779849,70.2765273 142.434839,71.2355558 143.325899,72.7903404 L154.343038,92.0138131 C155.225607,93.5537825 155.225607,95.4462175 154.343038,96.9861869 L143.325899,116.20966 C142.434839,117.764444 140.779849,118.723473 138.987827,118.723473 L117.017233,118.723473 C115.225211,118.723473 113.570221,117.764444 112.67916,116.20966 L101.662022,96.9861869 C100.779452,95.4462175 100.779452,93.5537825 101.662022,92.0138131 L112.67916,72.7903404 C113.570221,71.2355558 115.225211,70.2765273 117.017233,70.2765273 L138.987827,70.2765273 Z M135.080648,77.1414791 L120.924411,77.1414791 C119.134228,77.1414791 117.480644,78.0985567 116.5889,79.6508285 L116.5889,79.6508285 L109.489217,92.0093494 C108.603232,93.5515958 108.603232,95.4484042 109.489217,96.9906506 L109.489217,96.9906506 L116.5889,109.349172 C117.480644,110.901443 119.134228,111.858521 120.924411,111.858521 L120.924411,111.858521 L135.080648,111.858521 C136.870831,111.858521 138.524416,110.901443 139.41616,109.349172 L139.41616,109.349172 L146.515843,96.9906506 C147.401828,95.4484042 147.401828,93.5515958 146.515843,92.0093494 L146.515843,92.0093494 L139.41616,79.6508285 C138.524416,78.0985567 136.870831,77.1414791 135.080648,77.1414791 L135.080648,77.1414791 Z M131.319186,83.7122186 C133.108028,83.7122186 134.760587,84.6678753 135.652827,86.2183156 L138.983552,92.0060969 C139.87203,93.5500005 139.87203,95.4499995 138.983552,96.9939031 L135.652827,102.781684 C134.760587,104.332125 133.108028,105.287781 131.319186,105.287781 L124.685874,105.287781 C122.897032,105.287781 121.244473,104.332125 120.352233,102.781684 L117.021508,96.9939031 C116.13303,95.4499995 116.13303,93.5500005 117.021508,92.0060969 L120.352233,86.2183156 C121.244473,84.6678753 122.897032,83.7122186 124.685874,83.7122186 L131.319186,83.7122186 Z M128.003794,90.1848875 C126.459294,90.1848875 125.034382,91.0072828 124.263005,92.3424437 C123.491732,93.6774232 123.491732,95.3225768 124.263005,96.6575563 C125.034382,97.9927172 126.459294,98.8151125 128.001266,98.8151125 L128.001266,98.8151125 C129.545766,98.8151125 130.970678,97.9927172 131.742055,96.6575563 C132.513327,95.3225768 132.513327,93.6774232 131.742055,92.3424437 C130.970678,91.0072828 129.545766,90.1848875 128.003794,90.1848875 L128.003794,90.1848875 Z M93,94.5009646 L100.767764,94.5009646",
      id: "Polygon-2",
      fill: "#FFD94C"
    }),
    /*#__PURE__*/createVNode("path", {
      d: "M87.8601729,108.357758 C89.1715224,107.608286 90.8360246,108.074601 91.5779424,109.399303 L91.5779424,109.399303 L92.0525843,110.24352 C95.8563392,116.982993 99.8190116,123.380176 103.940602,129.435068 C108.807881,136.585427 114.28184,143.82411 120.362479,151.151115 C121.316878,152.30114 121.184944,154.011176 120.065686,154.997937 L120.065686,154.997937 L119.454208,155.534625 C99.3465389,173.103314 86.2778188,176.612552 80.2480482,166.062341 C74.3500652,155.742717 76.4844915,136.982888 86.6513274,109.782853 C86.876818,109.179582 87.3045861,108.675291 87.8601729,108.357758 Z M173.534177,129.041504 C174.986131,128.785177 176.375496,129.742138 176.65963,131.194242 L176.65963,131.194242 L176.812815,131.986376 C181.782365,157.995459 178.283348,171 166.315764,171 C154.609745,171 139.708724,159.909007 121.612702,137.727022 C121.211349,137.235047 120.994572,136.617371 121,135.981509 C121.013158,134.480686 122.235785,133.274651 123.730918,133.287756 L123.730918,133.287756 L124.684654,133.294531 C132.305698,133.335994 139.714387,133.071591 146.910723,132.501323 C155.409039,131.82788 164.283523,130.674607 173.534177,129.041504 Z M180.408726,73.8119663 C180.932139,72.4026903 182.508386,71.6634537 183.954581,72.149012 L183.954581,72.149012 L184.742552,72.4154854 C210.583763,81.217922 220.402356,90.8916805 214.198332,101.436761 C208.129904,111.751366 190.484347,119.260339 161.26166,123.963678 C160.613529,124.067994 159.948643,123.945969 159.382735,123.618843 C158.047025,122.846729 157.602046,121.158214 158.388848,119.847438 L158.388848,119.847438 L158.889328,119.0105 C162.877183,112.31633 166.481358,105.654262 169.701854,99.0242957 C173.50501,91.1948179 177.073967,82.7907081 180.408726,73.8119663 Z M94.7383398,66.0363218 C95.3864708,65.9320063 96.0513565,66.0540315 96.6172646,66.3811573 C97.9529754,67.153271 98.3979538,68.8417862 97.6111517,70.1525615 L97.6111517,70.1525615 L97.1106718,70.9895001 C93.1228168,77.6836699 89.5186416,84.3457379 86.2981462,90.9757043 C82.49499,98.8051821 78.9260328,107.209292 75.5912744,116.188034 C75.0678608,117.59731 73.4916142,118.336546 72.045419,117.850988 L72.045419,117.850988 L71.2574475,117.584515 C45.4162372,108.782078 35.597644,99.1083195 41.8016679,88.5632391 C47.8700957,78.2486335 65.515653,70.7396611 94.7383398,66.0363218 Z M136.545792,34.4653746 C156.653461,16.8966864 169.722181,13.3874478 175.751952,23.9376587 C181.649935,34.2572826 179.515508,53.0171122 169.348673,80.2171474 C169.123182,80.8204179 168.695414,81.324709 168.139827,81.6422422 C166.828478,82.3917144 165.163975,81.9253986 164.422058,80.6006966 L164.422058,80.6006966 L163.947416,79.7564798 C160.143661,73.0170065 156.180988,66.6198239 152.059398,60.564932 C147.192119,53.4145727 141.71816,46.1758903 135.637521,38.8488847 C134.683122,37.6988602 134.815056,35.9888243 135.934314,35.0020629 L135.934314,35.0020629 Z M90.6842361,18 C102.390255,18 117.291276,29.0909926 135.387298,51.2729777 C135.788651,51.7649527 136.005428,52.3826288 136,53.0184911 C135.986842,54.5193144 134.764215,55.7253489 133.269082,55.7122445 L133.269082,55.7122445 L132.315346,55.7054689 C124.694302,55.6640063 117.285613,55.9284091 110.089277,56.4986773 C101.590961,57.17212 92.7164767,58.325393 83.4658235,59.9584962 C82.0138691,60.2148231 80.6245044,59.2578618 80.3403697,57.805758 L80.3403697,57.805758 L80.1871846,57.0136235 C75.2176347,31.0045412 78.7166519,18 90.6842361,18 Z",
      id: "Combined-Shape",
      fill: "#FF4154"
    })
  ])
], -1 /* HOISTED */);

function render$4(_ctx, _cache) {
  return (openBlock(), createBlock("svg", _hoisted_1$3, [
    _hoisted_2$2
  ]))
}

const script$4 = {};


script$4.render = render$4;
script$4.__file = "src/devtools/Logo.vue";

const theme = {
    background: "#0b1521",
    backgroundAlt: "#132337",
    foreground: "white",
    gray: "#3f4e60",
    grayAlt: "#222e3e",
    inputBackgroundColor: "#fff",
    inputTextColor: "#000",
    success: "#00ab52",
    danger: "#ff0085",
    active: "#006bff",
    warning: "#ffb200",
};
const VUE_QUERY_DEVTOOLS_THEME = "VUE_QUERY_DEVTOOLS_THEME";
function useTheme() {
    return inject$1(VUE_QUERY_DEVTOOLS_THEME, theme);
}

var script$3 = defineComponent({
    name: "Explorer",
    props: {
        label: {},
        defaultExpanded: {
            type: Object,
        },
        pageSize: {
            type: Number,
            default: 100,
        },
        depth: {
            type: Number,
            default: 0,
        },
        value: {},
    },
    setup(props) {
        const theme = useTheme();
        const expanded = ref(props.defaultExpanded);
        const expandedPages = ref([]);
        const path = ref([]);
        const type = ref(typeof props.value);
        const subEntries = ref([]);
        const subEntryPages = ref([]);
        const toggle = (set) => {
            expanded.value = typeof set !== "undefined" ? set : !expanded.value;
        };
        const makeProperty = (sub) => {
            const newPath = path.value.concat(sub.label);
            let subDefaultExpanded = false;
            if (typeof props.defaultExpanded === "boolean") {
                if (props.defaultExpanded === true) {
                    subDefaultExpanded = { [sub.label]: true };
                }
            }
            else if (props.defaultExpanded) {
                subDefaultExpanded = props.defaultExpanded[sub.label];
            }
            return Object.assign(Object.assign({}, sub), { path: newPath, depth: props.depth + 1, defaultExpanded: subDefaultExpanded });
        };
        watchEffect(() => {
            if (Array.isArray(props.value)) {
                type.value = "array";
                subEntries.value = props.value.map((d, i) => {
                    return makeProperty({
                        label: i,
                        value: d,
                    });
                });
            }
            else if (props.value !== null &&
                typeof props.value === "object" &&
                typeof props.value[Symbol.iterator] === "function") {
                type.value = "Iterable";
                subEntries.value = Array.from(props.value, (val, i) => makeProperty({
                    label: i,
                    value: val,
                }));
            }
            else if (typeof props.value === "object" && props.value !== null) {
                type.value = "object";
                subEntries.value = Object.entries(props.value).map(([label, value]) => makeProperty({
                    label,
                    value,
                }));
            }
            if (subEntries.value) {
                let i = 0;
                while (i < subEntries.value.length) {
                    subEntryPages.value.push(subEntries.value.slice(i, i + props.pageSize));
                    i = i + props.pageSize;
                }
            }
        });
        const setExpandedPages = (index) => {
            if (expandedPages.value.includes(index)) {
                expandedPages.value = expandedPages.value.filter((d) => d !== index);
            }
            else {
                expandedPages.value = [...expandedPages.value, index];
            }
        };
        return {
            subEntryPages,
            toggle,
            expanded,
            subEntries,
            type,
            expandedPages,
            setExpandedPages,
            theme,
        };
    },
});

const _hoisted_1$2 = {
  key: 3,
  style: { cursor: 'pointer', color: 'white' }
};
const _hoisted_2$1 = /*#__PURE__*/createTextVNode(/*#__PURE__*/toDisplayString(" ") + " ");

function render$3(_ctx, _cache, $props, $setup, $data, $options) {
  const _component__self = resolveComponent("_self");

  return (openBlock(), createBlock("div", {
    style: {
      fontFamily: 'Menlo, monospace',
      fontSize: '0.9rem',
      lineHeight: '1.7',
      outline: 'none',
      wordBreak: 'break-word',
    },
    key: _ctx.label
  }, [
    (_ctx.subEntryPages?.length)
      ? (openBlock(), createBlock("span", {
          key: 0,
          style: { cursor: 'pointer', color: 'white' },
          onClick: _cache[1] || (_cache[1] = () => _ctx.toggle())
        }, [
          createVNode("span", {
            style: {
          display: 'inline-block',
          transition: 'all .1s ease',
          transform: `rotate(${_ctx.expanded ? 90 : 0}deg)`,
        }
          }, " ▶ ", 4 /* STYLE */),
          createTextVNode(" " + toDisplayString(_ctx.label) + toDisplayString(" ") + " ", 1 /* TEXT */),
          createVNode("span", { style: { color: 'grey', fontSize: '.7rem' } }, toDisplayString(String(_ctx.type).toLowerCase() === "iterable" ? "(Iterable) " : "") + " " + toDisplayString(_ctx.subEntries.length) + " " + toDisplayString(_ctx.subEntries.length > 1 ? `items` : `item`), 5 /* TEXT, STYLE */)
        ]))
      : createCommentVNode("v-if", true),
    (_ctx.expanded && _ctx.subEntryPages.length === 1)
      ? (openBlock(), createBlock("div", {
          key: 1,
          style: {
        marginLeft: '.1rem',
        paddingLeft: '1rem',
        borderLeft: '2px solid rgba(0,0,0,.15)',
      }
        }, [
          (openBlock(true), createBlock(Fragment, null, renderList(_ctx.subEntries, (entry) => {
            return (openBlock(), createBlock(_component__self, {
              key: entry.label,
              label: entry.label,
              value: entry.value
            }, null, 8 /* PROPS */, ["label", "value"]))
          }), 128 /* KEYED_FRAGMENT */))
        ], 4 /* STYLE */))
      : createCommentVNode("v-if", true),
    (_ctx.expanded && _ctx.subEntryPages.length !== 1)
      ? (openBlock(), createBlock("div", {
          key: 2,
          style: {
        marginLeft: '.1rem',
        paddingLeft: '1rem',
        borderLeft: '2px solid rgba(0,0,0,.15)',
      }
        }, [
          (openBlock(true), createBlock(Fragment, null, renderList(_ctx.subEntryPages, (entries, index) => {
            return (openBlock(), createBlock("div", { key: index }, [
              createVNode("div", { style: {
            fontFamily: 'Menlo, monospace',
            fontSize: '0.9rem',
            lineHeight: '1.7',
            outline: 'none',
            wordBreak: 'break-word',
          } }, [
                createVNode("span", {
                  style: { cursor: 'pointer', color: 'white' },
                  onClick: () => _ctx.setExpandedPages(index)
                }, [
                  createVNode("span", {
                    style: {
                display: 'inline-block',
                transition: 'all .1s ease',
                transform: `rotate(${_ctx.expanded ? 90 : 0}deg)`,
              }
                  }, " ▶ ", 4 /* STYLE */),
                  createTextVNode(" [" + toDisplayString(index * _ctx.pageSize) + " ..." + toDisplayString(" ") + " " + toDisplayString(index * _ctx.pageSize + _ctx.pageSize - 1) + "] ", 1 /* TEXT */)
                ], 8 /* PROPS */, ["onClick"]),
                (_ctx.expandedPages.includes(index))
                  ? (openBlock(), createBlock("div", {
                      key: 0,
                      style: {
              marginLeft: '.1rem',
              paddingLeft: '1rem',
              borderLeft: '2px solid rgba(0,0,0,.15)',
            }
                    }, [
                      (openBlock(true), createBlock(Fragment, null, renderList(entries, (entry) => {
                        return (openBlock(), createBlock(_component__self, {
                          key: entry.label,
                          label: entry.label,
                          value: entry.value
                        }, null, 8 /* PROPS */, ["label", "value"]))
                      }), 128 /* KEYED_FRAGMENT */))
                    ], 4 /* STYLE */))
                  : createCommentVNode("v-if", true)
              ], 4 /* STYLE */)
            ]))
          }), 128 /* KEYED_FRAGMENT */))
        ], 4 /* STYLE */))
      : createCommentVNode("v-if", true),
    (!_ctx.subEntryPages?.length)
      ? (openBlock(), createBlock("span", _hoisted_1$2, toDisplayString(_ctx.label) + ":", 1 /* TEXT */))
      : createCommentVNode("v-if", true),
    _hoisted_2$1,
    (!_ctx.subEntryPages?.length)
      ? (openBlock(), createBlock("span", {
          key: 4,
          style: { color: _ctx.theme.danger }
        }, toDisplayString(JSON.stringify(_ctx.value, Object.getOwnPropertyNames(Object(_ctx.value)))), 5 /* TEXT, STYLE */))
      : createCommentVNode("v-if", true)
  ], 4 /* STYLE */))
}

script$3.render = render$3;
script$3.__file = "src/devtools/Explorer.vue";

var script$2 = defineComponent({
    name: "DevtoolsPanel",
    components: { Logo: script$4, Explorer: script$3 },
    props: {
        isOpen: {
            type: Boolean,
            required: true,
        },
        panelProps: {
            type: Object,
            default: () => ({}),
        },
    },
    setup(props) {
        const theme = useTheme();
        const devToolsHeight = ref(400);
        const sort = ref(Object.keys(sortFns)[0]);
        const filter = ref("");
        const sortDesc = ref(false);
        const activeQueryHash = ref("");
        const sortFn = computed(() => sortFns[sort.value]);
        const devtoolsPanelStyles = computed(() => {
            var _a;
            return (Object.assign(Object.assign(Object.assign({ display: "flex", position: "fixed", bottom: "0", right: "0", background: "#0b1521", color: "#fff", zIndex: "99999", width: "100%", height: ((_a = devToolsHeight.value) !== null && _a !== void 0 ? _a : 500) + "px", maxHeight: "90%", boxShadow: "0 0 20px rgba(0,0,0,.3)", borderTop: `1px solid ${theme.gray}`, transformOrigin: "top" }, (props.panelProps.style || {})), { transition: `all .2s ease` }), (props.isOpen
                ? {
                    opacity: 1,
                    pointerEvents: "all",
                    transform: `translateY(0) scale(1)`,
                }
                : {
                    opacity: 0,
                    pointerEvents: "none",
                    transform: `translateY(15px) scale(1.02)`,
                })));
        });
        const queryClient = useQueryClient();
        const queryCache = queryClient.getQueryCache();
        const unsortedQueries = ref(Object.values(queryCache.findAll()));
        const queries = computed(() => {
            const sorted = [...unsortedQueries.value].sort(sortFn.value);
            if (sortDesc.value) {
                sorted.reverse();
            }
            if (!filter.value) {
                return sorted;
            }
            return matchSorter(sorted, filter.value, { keys: ["queryHash"] }).filter((d) => d.queryHash);
        });
        const activeQuery = computed(() => {
            return queries.value.find((query) => query.queryHash === activeQueryHash.value);
        });
        const hasFresh = computed(() => {
            return queries.value.filter((q) => getQueryStatusLabel(q) === "fresh")
                .length;
        });
        const hasFetching = computed(() => {
            return queries.value.filter((q) => getQueryStatusLabel(q) === "fetching")
                .length;
        });
        const hasStale = computed(() => {
            return queries.value.filter((q) => getQueryStatusLabel(q) === "stale")
                .length;
        });
        const hasInactive = computed(() => {
            return queries.value.filter((q) => getQueryStatusLabel(q) === "inactive")
                .length;
        });
        queryCache.subscribe(() => {
            unsortedQueries.value = Object.values(queryCache.getAll());
        });
        const onChange = (event) => {
            var _a;
            filter.value = (_a = event.target) === null || _a === void 0 ? void 0 : _a.value;
        };
        const onKeyDown = (event) => {
            if (event.key === "Escape") {
                filter.value = "";
            }
        };
        const onSortChange = (event) => {
            var _a;
            sort.value = (_a = event.target) === null || _a === void 0 ? void 0 : _a.value;
        };
        const onSortDescChange = () => {
            sortDesc.value = !sortDesc.value;
        };
        const onQueryClick = (query) => {
            activeQueryHash.value =
                activeQueryHash.value === query.queryHash ? "" : query.queryHash;
        };
        return {
            devtoolsPanelStyles,
            queries,
            activeQuery,
            filter,
            sort,
            sortFns,
            sortDesc,
            hasFresh,
            hasFetching,
            hasStale,
            hasInactive,
            theme,
            getQueryStatusColor,
            getQueryStatusLabel,
            onChange,
            onKeyDown,
            onSortChange,
            onSortDescChange,
            onQueryClick,
            queryClient,
        };
    },
});

const _withId = /*#__PURE__*/withScopeId("data-v-6c1bb3ce");

pushScopeId("data-v-6c1bb3ce");
const _hoisted_1$1 = { style: {
            display: 'flex',
            flexDirection: 'column',
          } };
const _hoisted_2 = { class: "query-keys" };
const _hoisted_3 = /*#__PURE__*/createTextVNode(" fresh ");
const _hoisted_4 = { class: "code" };
const _hoisted_5 = /*#__PURE__*/createTextVNode(" fetching ");
const _hoisted_6 = { class: "code" };
const _hoisted_7 = /*#__PURE__*/createTextVNode(" stale ");
const _hoisted_8 = { class: "code" };
const _hoisted_9 = /*#__PURE__*/createTextVNode(" inactive ");
const _hoisted_10 = { class: "code" };
const _hoisted_11 = { style: {
              display: 'flex',
              alignItems: 'center',
            } };
const _hoisted_12 = { style: {
          overflowY: 'auto',
          flex: '1',
        } };
const _hoisted_13 = {
  key: 0,
  style: {
        flex: '1 1 500px',
        display: 'flex',
        flexDirection: 'column',
        overflow: 'auto',
        height: '100%',
      }
};
const _hoisted_14 = { style: {
                margin: 0,
                padding: 0,
                overflow: 'auto',
              } };
const _hoisted_15 = /*#__PURE__*/createTextVNode(" Observers: ");
const _hoisted_16 = { style: {
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'space-between',
          } };
const _hoisted_17 = /*#__PURE__*/createTextVNode(" Last Updated:" + /*#__PURE__*/toDisplayString(" ") + " ");
const _hoisted_18 = /*#__PURE__*/createTextVNode(/*#__PURE__*/toDisplayString(" ") + " ");
const _hoisted_19 = /*#__PURE__*/createTextVNode(/*#__PURE__*/toDisplayString(" ") + " ");
const _hoisted_20 = /*#__PURE__*/createTextVNode(/*#__PURE__*/toDisplayString(" ") + " ");
popScopeId();

const render$2 = /*#__PURE__*/_withId((_ctx, _cache, $props, $setup, $data, $options) => {
  const _component_Logo = resolveComponent("Logo");
  const _component_Explorer = resolveComponent("Explorer");

  return (openBlock(), createBlock("div", {
    class: "VueQueryDevtoolsPanel",
    style: _ctx.devtoolsPanelStyles
  }, [
    createVNode("div", {
      style: {
        flex: '1 1 500px',
        minHeight: '40%',
        maxHeight: '100%',
        overflow: 'auto',
        borderRight: `1px solid ${_ctx.theme.grayAlt}`,
        display: 'flex',
        flexDirection: 'column',
      }
    }, [
      createVNode("div", {
        style: {
          padding: '.5rem',
          background: _ctx.theme.backgroundAlt,
          display: 'flex',
          justifyContent: 'space-between',
          alignItems: 'center',
        }
      }, [
        createVNode(_component_Logo, {
          "aria-hidden": "",
          style: {
            marginRight: '.5rem',
          }
        }, null, 8 /* PROPS */, ["style"]),
        createVNode("div", _hoisted_1$1, [
          createVNode("span", _hoisted_2, [
            createVNode("span", {
              class: "query-key",
              style: {
                background: _ctx.theme.success,
                opacity: _ctx.hasFresh ? 1 : 0.3,
              }
            }, [
              _hoisted_3,
              createVNode("code", _hoisted_4, toDisplayString(_ctx.hasFresh), 1 /* TEXT */)
            ], 4 /* STYLE */),
            createVNode("span", {
              class: "query-key",
              style: {
                background: _ctx.theme.active,
                opacity: _ctx.hasFetching ? 1 : 0.3,
              }
            }, [
              _hoisted_5,
              createVNode("code", _hoisted_6, toDisplayString(_ctx.hasFetching), 1 /* TEXT */)
            ], 4 /* STYLE */),
            createVNode("span", {
              class: "query-key",
              style: {
                background: _ctx.theme.warning,
                color: 'black',
                textShadow: '0',
                opacity: _ctx.hasStale ? 1 : 0.3,
              }
            }, [
              _hoisted_7,
              createVNode("code", _hoisted_8, toDisplayString(_ctx.hasStale), 1 /* TEXT */)
            ], 4 /* STYLE */),
            createVNode("span", {
              class: "query-key",
              style: {
                background: _ctx.theme.gray,
                opacity: _ctx.hasInactive ? 1 : 0.3,
              }
            }, [
              _hoisted_9,
              createVNode("code", _hoisted_10, toDisplayString(_ctx.hasInactive), 1 /* TEXT */)
            ], 4 /* STYLE */)
          ]),
          createVNode("div", _hoisted_11, [
            createVNode("input", {
              class: "input",
              placeholder: "Filter",
              value: _ctx.filter ?? '',
              onInput: _cache[1] || (_cache[1] = (...args) => (_ctx.onChange && _ctx.onChange(...args))),
              onKeydown: _cache[2] || (_cache[2] = (...args) => (_ctx.onKeyDown && _ctx.onKeyDown(...args))),
              style: {
                flex: '1',
                marginRight: '.5rem',
                backgroundColor: _ctx.theme.inputBackgroundColor,
                color: _ctx.theme.inputTextColor,
              }
            }, null, 44 /* STYLE, PROPS, HYDRATE_EVENTS */, ["value"]),
            createVNode("div", null, [
              (!_ctx.filter)
                ? (openBlock(), createBlock("select", {
                    key: 0,
                    class: "select",
                    value: _ctx.sort,
                    onChange: _cache[3] || (_cache[3] = (...args) => (_ctx.onSortChange && _ctx.onSortChange(...args))),
                    style: {
                  flex: '1',
                  minWidth: 75,
                  marginRight: '.5rem',
                  backgroundColor: _ctx.theme.inputBackgroundColor,
                  color: _ctx.theme.inputTextColor,
                }
                  }, [
                    (openBlock(true), createBlock(Fragment, null, renderList(Object.keys(_ctx.sortFns), (key) => {
                      return (openBlock(), createBlock("option", {
                        key: key,
                        value: key
                      }, " Sort by " + toDisplayString(key), 9 /* TEXT, PROPS */, ["value"]))
                    }), 128 /* KEYED_FRAGMENT */))
                  ], 44 /* STYLE, PROPS, HYDRATE_EVENTS */, ["value"]))
                : createCommentVNode("v-if", true),
              createVNode("button", {
                class: "button",
                type: "button",
                onClick: _cache[4] || (_cache[4] = (...args) => (_ctx.onSortDescChange && _ctx.onSortDescChange(...args))),
                style: {
                  padding: '.3rem .4rem',
                  background: _ctx.theme.gray,
                }
              }, toDisplayString(_ctx.sortDesc ? "⬇ Desc" : "⬆ Asc"), 5 /* TEXT, STYLE */)
            ])
          ])
        ])
      ], 4 /* STYLE */),
      createVNode("div", _hoisted_12, [
        (openBlock(true), createBlock(Fragment, null, renderList(_ctx.queries, (query) => {
          return (openBlock(), createBlock("div", {
            key: query.queryHash,
            onClick: () => _ctx.onQueryClick(query),
            style: {
            display: 'flex',
            borderBottom: `solid 1px ${_ctx.theme.grayAlt}`,
            cursor: 'pointer',
            background:
              query === _ctx.activeQuery ? 'rgba(255,255,255,.1)' : undefined,
          }
          }, [
            createVNode("div", {
              style: {
              flex: '0 0 auto',
              width: '2rem',
              height: '2rem',
              background: _ctx.getQueryStatusColor(query, _ctx.theme),
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center',
              fontWeight: 'bold',
              textShadow:
                _ctx.getQueryStatusLabel(query) === 'stale' ? '0' : '0 0 10px black',
              color: _ctx.getQueryStatusLabel(query) === 'stale' ? 'black' : 'white',
            }
            }, toDisplayString(query.observers.length), 5 /* TEXT, STYLE */),
            createVNode("code", {
              class: "code",
              style: {
              padding: '.5rem',
            }
            }, toDisplayString(query.queryHash), 5 /* TEXT, STYLE */)
          ], 12 /* STYLE, PROPS */, ["onClick"]))
        }), 128 /* KEYED_FRAGMENT */))
      ])
    ], 4 /* STYLE */),
    (_ctx.activeQuery)
      ? (openBlock(), createBlock("div", _hoisted_13, [
          createVNode("div", {
            style: {
          padding: '.5rem',
          background: _ctx.theme.backgroundAlt,
          position: 'sticky',
          top: 0,
          zIndex: 1,
        }
          }, " Query Details ", 4 /* STYLE */),
          createVNode("div", { style: {
          padding: '.5rem',
        } }, [
            createVNode("div", { style: {
            marginBottom: '.5rem',
            display: 'flex',
            alignItems: 'stretch',
            justifyContent: 'space-between',
          } }, [
              createVNode("code", { style: {
              lineHeight: '1.8rem',
              fontSize: '.9em',
            } }, [
                createVNode("pre", _hoisted_14, toDisplayString(JSON.stringify(_ctx.activeQuery.queryKey, null, 2)), 1 /* TEXT */)
              ], 4 /* STYLE */),
              createVNode("span", {
                style: {
              padding: '0.3rem .6rem',
              borderRadius: '0.4rem',
              fontWeight: 'bold',
              textShadow: '0 2px 10px black',
              background: _ctx.getQueryStatusColor(_ctx.activeQuery, _ctx.theme),
              flexShrink: 0,
            }
              }, toDisplayString(_ctx.getQueryStatusLabel(_ctx.activeQuery)), 5 /* TEXT, STYLE */)
            ], 4 /* STYLE */),
            createVNode("div", { style: {
            marginBottom: '.5rem',
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'space-between',
          } }, [
              _hoisted_15,
              createVNode("code", { style: { fontSize: '.9em' } }, toDisplayString(_ctx.activeQuery.observers.length), 5 /* TEXT, STYLE */)
            ], 4 /* STYLE */),
            createVNode("div", _hoisted_16, [
              _hoisted_17,
              createVNode("code", { style: { fontSize: '.9em' } }, toDisplayString(new Date(_ctx.activeQuery.state.dataUpdatedAt).toLocaleTimeString()), 5 /* TEXT, STYLE */)
            ])
          ], 4 /* STYLE */),
          createVNode("div", {
            style: {
          background: _ctx.theme.backgroundAlt,
          padding: '.5rem',
          position: 'sticky',
          top: 0,
          zIndex: 1,
        }
          }, " Actions ", 4 /* STYLE */),
          createVNode("div", { style: {
          padding: '0.5rem',
        } }, [
            createVNode("button", {
              class: "button",
              type: "button",
              onClick: _cache[5] || (_cache[5] = () => _ctx.activeQuery?.fetch()),
              disabled: _ctx.activeQuery.state.isFetching,
              style: {
            background: _ctx.theme.active,
          }
            }, " Refetch", 12 /* STYLE, PROPS */, ["disabled"]),
            _hoisted_18,
            createVNode("button", {
              class: "button",
              type: "button",
              onClick: _cache[6] || (_cache[6] = () => _ctx.queryClient.invalidateQueries(_ctx.activeQuery)),
              style: {
            background: _ctx.theme.warning,
            color: _ctx.theme.inputTextColor,
          }
            }, " Invalidate", 4 /* STYLE */),
            _hoisted_19,
            createVNode("button", {
              class: "button",
              type: "button",
              onClick: _cache[7] || (_cache[7] = () => _ctx.queryClient.resetQueries(_ctx.activeQuery)),
              style: {
            background: _ctx.theme.gray,
          }
            }, " Reset", 4 /* STYLE */),
            _hoisted_20,
            createVNode("button", {
              class: "button",
              type: "button",
              onClick: _cache[8] || (_cache[8] = () => _ctx.queryClient.removeQueries(_ctx.activeQuery)),
              style: {
            background: _ctx.theme.danger,
          }
            }, " Remove ", 4 /* STYLE */)
          ], 4 /* STYLE */),
          createVNode("div", {
            style: {
          background: _ctx.theme.backgroundAlt,
          padding: '.5rem',
          position: 'sticky',
          top: 0,
          zIndex: 1,
        }
          }, " Data Explorer ", 4 /* STYLE */),
          createVNode("div", { style: {
          padding: '.5rem',
        } }, [
            createVNode(_component_Explorer, {
              label: "Data",
              value: _ctx.activeQuery?.state?.data,
              defaultExpanded: {}
            }, null, 8 /* PROPS */, ["value"])
          ], 4 /* STYLE */),
          createVNode("div", {
            style: {
          background: _ctx.theme.backgroundAlt,
          padding: '.5rem',
          position: 'sticky',
          top: 0,
          zIndex: 1,
        }
          }, " Query Explorer ", 4 /* STYLE */),
          createVNode("div", { style: {
          padding: '.5rem',
        } }, [
            createVNode(_component_Explorer, {
              label: "Query",
              value: _ctx.activeQuery,
              defaultExpanded: {
            queryKey: true,
          }
            }, null, 8 /* PROPS */, ["value"])
          ], 4 /* STYLE */)
        ]))
      : createCommentVNode("v-if", true)
  ], 4 /* STYLE */))
});

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "\n.query-keys[data-v-6c1bb3ce] {\n  display: inline-block;\n  font-size: 0.9em;\n  margin-bottom: 0.5rem;\n}\n.query-keys .query-key[data-v-6c1bb3ce] {\n  margin-left: 5px;\n}\n.query-key[data-v-6c1bb3ce] {\n  display: inline-flex;\n  align-items: center;\n  padding: 0.2em 0.4em;\n  font-weight: bold;\n  text-shadow: 0 0 10px black;\n  border-radius: 0.2em;\n}\n.query-key .code[data-v-6c1bb3ce] {\n  padding-left: 5px;\n}\n.code[data-v-6c1bb3ce] {\n  font-size: 0.9em;\n}\n.input[data-v-6c1bb3ce] {\n  border: 0;\n  border-radius: 0.2em;\n  font-size: 0.9em;\n  line-height: 1.3;\n  padding: 0.3em 0.4em;\n}\n.button[data-v-6c1bb3ce] {\n  background: #3f4e60;\n  appearance: none;\n  font-size: 0.9em;\n  font-weight: bold;\n  border: 0;\n  border-radius: 0.3em;\n  color: white;\n  padding: 0.5em;\n  cursor: pointer;\n}\n.select[data-v-6c1bb3ce] {\n  display: inline-block;\n  font-size: 0.9em;\n  font-family: sans-serif;\n  font-weight: normal;\n  line-height: 1.3;\n  padding: 0.3em 1.5em 0.3em 0.5em;\n  height: auto;\n  border: 0;\n  border-radius: 0.2em;\n  appearance: none;\n  --webkit-appearance: none;\n  background-image: url(\"data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' width='100' height='100' fill='%23444444'><polygon points='0,25 100,25 50,75'/></svg>\");\n  background-repeat: no-repeat;\n  background-position: right 0.55em center;\n  background-size: 0.65em auto, 100%;\n}\n";
styleInject(css_248z);

script$2.render = render$2;
script$2.__scopeId = "data-v-6c1bb3ce";
script$2.__file = "src/devtools/DevtoolsPanel.vue";

var script$1 = defineComponent({
    name: "ToggleButton",
    components: { Logo: script$4 },
    props: {
        position: {
            type: String,
            required: true,
        },
        buttonProps: {
            type: Object,
            default: {},
        },
    },
    emits: ["click"],
    setup(props, context) {
        const onClick = () => {
            var _a, _b;
            context.emit("click");
            (_b = (_a = props.buttonProps).click) === null || _b === void 0 ? void 0 : _b.call(_a);
        };
        const buttonStyles = computed(() => (Object.assign(Object.assign({ background: "none", border: 0, padding: 0, position: "fixed", zIndex: "99999", display: "inline-flex", fontSize: "1.5rem", margin: ".5rem", cursor: "pointer", width: "fit-content" }, (props.position === Position.TR
            ? {
                top: "0",
                right: "0",
            }
            : props.position === Position.TL
                ? {
                    top: "0",
                    left: "0",
                }
                : props.position === Position.BR
                    ? {
                        bottom: "0",
                        right: "0",
                    }
                    : {
                        bottom: "0",
                        left: "0",
                    })), props.buttonProps.style)));
        return {
            onClick,
            buttonStyles,
        };
    },
});

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_logo = resolveComponent("logo");

  return (openBlock(), createBlock("button", {
    type: "button",
    "aria-label": "Open Vue Query Devtools",
    onClick: _cache[1] || (_cache[1] = (...args) => (_ctx.onClick && _ctx.onClick(...args))),
    style: _ctx.buttonStyles
  }, [
    createVNode(_component_logo)
  ], 4 /* STYLE */))
}

script$1.render = render$1;
script$1.__file = "src/devtools/ToggleButton.vue";

var script = defineComponent({
    name: "VueQueryDevTools",
    components: { CloseButton: script$5, DevtoolsPanel: script$2, ToggleButton: script$1 },
    props: {
        initialIsOpen: {
            type: Boolean,
            default: false,
        },
        panelProps: {
            type: Object,
            default: {},
        },
        closeButtonProps: {
            type: Object,
            default: {},
        },
        toggleButtonProps: {
            type: Object,
            default: {},
        },
        position: {
            type: String,
            default: Position.BL,
        },
        containerElement: {
            type: String,
            default: "footer",
        },
    },
    setup(props) {
        const isOpen = ref(props.initialIsOpen);
        const devtoolsHeight = ref(200);
        const onToggleClick = () => {
            isOpen.value = !isOpen.value;
        };
        return {
            isOpen,
            devtoolsHeight,
            onToggleClick,
        };
    },
});

const _hoisted_1 = { class: "VueQueryDevtools" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_DevtoolsPanel = resolveComponent("DevtoolsPanel");
  const _component_CloseButton = resolveComponent("CloseButton");
  const _component_ToggleButton = resolveComponent("ToggleButton");

  return (openBlock(), createBlock("div", _hoisted_1, [
    createVNode(_component_DevtoolsPanel, {
      isOpen: _ctx.isOpen,
      panelProps: _ctx.panelProps
    }, null, 8 /* PROPS */, ["isOpen", "panelProps"]),
    (_ctx.isOpen)
      ? (openBlock(), createBlock(_component_CloseButton, {
          key: 0,
          position: _ctx.position,
          buttonProps: _ctx.closeButtonProps,
          onClick: _ctx.onToggleClick
        }, null, 8 /* PROPS */, ["position", "buttonProps", "onClick"]))
      : createCommentVNode("v-if", true),
    (!_ctx.isOpen)
      ? (openBlock(), createBlock(_component_ToggleButton, {
          key: 1,
          position: _ctx.position,
          buttonProps: _ctx.toggleButtonProps,
          onClick: _ctx.onToggleClick
        }, null, 8 /* PROPS */, ["position", "buttonProps", "onClick"]))
      : createCommentVNode("v-if", true)
  ]))
}

script.render = render;
script.__file = "src/devtools/Devtools.vue";

export { VUE_QUERY_DEVTOOLS_THEME, script as VueQueryDevTools, script$2 as VueQueryDevToolsPanel };
//# sourceMappingURL=devtools-bundle.js.map
